Demo
====

| An example app utilising ``django-trench`` is available live on `django-trench.herokuapp.com`_
| Demo app can be run locally straight from the source code. Check out :doc:`examples`.


.. _django-trench.herokuapp.com: http://django-trench.herokuapp.com
